@@ -17,7 +17,7 @@ use Net::CIDR::Lite;
 
 #parameter syslog Indicates syslog facility for logging user actions
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.9.1';
 our $_SUPER;
 our @ISA;
 
@@ -122,7 +122,7 @@ sub lmLog {
     else {
         $self->{hideLogLevels} = 'debug|info'
           unless defined( $self->{hideLogLevels} );
-        my $re = qr/^(?:$self->{hideLogLevels})$/;
+        my $re = qr/^(?:$self->{hideLogLevels})$/o;
         print STDERR "$call\n" if ( $call and 'debug' !~ $re );
         print STDERR "[$level] $mess\n" unless ( $level =~ $re );
     }
